@@ -25,7 +25,7 @@ package Ftree::DataParsers::ExtendedSimonWardFormat;
 require Ftree::DataParsers::ArrayImporters::CSVArrayImporter;
 use strict;
 use warnings;
-use version; our $VERSION = qv('2.3.35');
+use version; our $VERSION = qv('2.3.36');
 
 use Ftree::Name;
 use Ftree::Picture;
@@ -103,7 +103,7 @@ sub createFamilyTreeDataFromFile {
   my $arrayImporter = Ftree::DataParsers::ArrayImporters::CSVArrayImporter->new($file_name, $encoding);
   while ($arrayImporter->hasNext()) {
     my @fields = $arrayImporter->next();
-    @fields = map {StringUtils::trim($_)} @fields;
+    @fields = map {Ftree::StringUtils::trim($_)} @fields;
 
     my $name_ref = getNameFields($fields[0]);
     my ( $date_of_birth, $date_of_death ) = defined $fields[5] ?
